==> handsontable-4.0.0.tgz: package/test/e2e/mobile/scroll.spec.js <==
const id = 'testContainer';

beforeEach(function () {
  this.$container = $(`<div id="${id}"></div>`).appendTo('body');
});

afterEach(function () {
  if (this.$container) {
    destroy();
    this.$container.remove();
  }
});

describe('Scrolling', () => {
  it('should load cells below the viewport on scroll down (dimensions of the table was set)', async () => {
    const hot = handsontable({
      width: 400,
      height: 400,
      data: Handsontable.helper.createSpreadsheetObjectData(100, 15)
    });

    const mainHolder = hot.view.wt.wtTable.holder;
    const $htCore = $(getHtCore());

    let TRs = $htCore.find('tr');
    let lastTR = [...TRs].pop();
    let lastTRTextAtStart = $(lastTR).text();

    $(mainHolder).scrollTop(400);

    await sleep(300);

    TRs = $htCore.find('tr');
    lastTR = [...TRs].pop();
    let lastTRTextLater = $(lastTR).text();

    expect(lastTRTextLater).not.toEqual(lastTRTextAtStart);
  });

  it('should load cells below the viewport on scroll down (dimensions of the table was not set)', async () => {
    handsontable({
      data: Handsontable.helper.createSpreadsheetObjectData(100, 15)
    });

    const $htCore = $(getHtCore());

    let TRs = $htCore.find('tr');
    let lastTR = [...TRs].pop();
    let lastTRTextAtStart = $(lastTR).text();

    await sleep(300);

    $(window).scrollTop(window.innerHeight);

    await sleep(300);

    TRs = $htCore.find('tr');
    lastTR = [...TRs].pop();
    let lastTRTextLater = $(lastTR).text();

    expect(lastTRTextLater).not.toEqual(lastTRTextAtStart);
  });
});

==> handsontable-6.0.1.tgz: package/test/e2e/mobile/scroll.spec.js <==
const id = 'testContainer';

beforeEach(function() {
  this.$container = $(`<div id="${id}"></div>`).appendTo('body');
});

afterEach(function() {
  if (this.$container) {
    destroy();
    this.$container.remove();
  }
});

describe('Scrolling', () => {
  it('should load cells below the viewport on scroll down (dimensions of the table was set)', async() => {
    const hot = handsontable({
      width: 400,
      height: 400,
      data: Handsontable.helper.createSpreadsheetObjectData(100, 15)
    });

    const mainHolder = hot.view.wt.wtTable.holder;
    const $htCore = $(getHtCore());

    let TRs = $htCore.find('tr');
    let lastTR = [...TRs].pop();
    const lastTRTextAtStart = $(lastTR).text();

    $(mainHolder).scrollTop(400);

    await sleep(300);

    TRs = $htCore.find('tr');
    lastTR = [...TRs].pop();
    const lastTRTextLater = $(lastTR).text();

    expect(lastTRTextLater).not.toEqual(lastTRTextAtStart);
  });

  it('should load cells below the viewport on scroll down (dimensions of the table was not set)', async() => {
    handsontable({
      data: Handsontable.helper.createSpreadsheetObjectData(100, 15)
    });

    const $htCore = $(getHtCore());

    let TRs = $htCore.find('tr');
    let lastTR = [...TRs].pop();
    const lastTRTextAtStart = $(lastTR).text();

    await sleep(300);

    $(window).scrollTop(window.innerHeight);

    await sleep(300);

    TRs = $htCore.find('tr');
    lastTR = [...TRs].pop();
    const lastTRTextLater = $(lastTR).text();

    expect(lastTRTextLater).not.toEqual(lastTRTextAtStart);
  });
});
